package org.gcube.portlets.user.td.resourceswidget.client;



import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.ResourceTDDescriptor;
import org.gcube.portlets.user.td.resourceswidget.client.charts.ChartViewerDialog;
import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;

import com.allen_sauer.gwt.log.client.Log;
import com.google.gwt.core.client.EntryPoint;
import com.google.web.bindery.event.shared.EventBus;
import com.google.web.bindery.event.shared.SimpleEventBus;

/**
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public class ResourcesWidgetEntry  implements EntryPoint  {

	
	private ResourceTDDescriptor resourceTDDescriptor;

	public void onModuleLoad() {
		EventBus eventBus= new SimpleEventBus();
	
		
		TRId trId=new TRId();
		//For example Tabular Resource 7 and table 402
		trId.setId("7");
		trId.setTableId("402");
		
		//ResourcesDialog dialog=new ResourcesDialog(trId,eventBus);
		//dialog.show();
		
		resourceTDDescriptor=new ResourceTDDescriptor();
		resourceTDDescriptor.setName("Test Chart");
		ChartViewerDialog chartDialog=new ChartViewerDialog(resourceTDDescriptor, trId, eventBus, true);
		chartDialog.show();
		
		Log.info("Hello!");
	}
}
